summaryrefslogtreecommitdiffstats
path: root/kresources/newexchange
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/newexchange')
-rw-r--r--kresources/newexchange/exchangeaddressbookadaptor.cpp4
-rw-r--r--kresources/newexchange/exchangeaddressbookadaptor.h18
-rw-r--r--kresources/newexchange/exchangecalendaradaptor.cpp22
-rw-r--r--kresources/newexchange/exchangecalendaradaptor.h22
-rw-r--r--kresources/newexchange/exchangeconvertercalendar.cpp152
-rw-r--r--kresources/newexchange/exchangeconvertercalendar.h28
-rw-r--r--kresources/newexchange/exchangeconvertercontact.cpp78
-rw-r--r--kresources/newexchange/exchangeconvertercontact.h20
-rw-r--r--kresources/newexchange/exchangeglobals.cpp70
-rw-r--r--kresources/newexchange/exchangeglobals.h16
-rw-r--r--kresources/newexchange/kabc_resourceexchange.h2
11 files changed, 216 insertions, 216 deletions
diff --git a/kresources/newexchange/exchangeaddressbookadaptor.cpp b/kresources/newexchange/exchangeaddressbookadaptor.cpp
index 469d15c3..423ac75a 100644
--- a/kresources/newexchange/exchangeaddressbookadaptor.cpp
+++ b/kresources/newexchange/exchangeaddressbookadaptor.cpp
@@ -82,9 +82,9 @@ void ExchangeAddressBookAdaptor::customAdaptUploadUrl( KURL &url )
// url.setPath( url.path() + "/NewItem.EML" );
}
-QString ExchangeAddressBookAdaptor::defaultNewItemName( KPIM::GroupwareUploadItem *item ) {
+TQString ExchangeAddressBookAdaptor::defaultNewItemName( KPIM::GroupwareUploadItem *item ) {
if ( item ) return item->uid()+".EML";
- else return QString::null;
+ else return TQString::null;
}
diff --git a/kresources/newexchange/exchangeaddressbookadaptor.h b/kresources/newexchange/exchangeaddressbookadaptor.h
index 7d340bfb..2d3df742 100644
--- a/kresources/newexchange/exchangeaddressbookadaptor.h
+++ b/kresources/newexchange/exchangeaddressbookadaptor.h
@@ -31,7 +31,7 @@
#include <kabc/addressee.h>
#include <kurl.h>
-#include <qdom.h>
+#include <tqdom.h>
namespace KABC {
@@ -47,7 +47,7 @@ class ExchangeAddressBookUploadItem : public KPIM::GroupwareUploadItem
protected:
ExchangeAddressBookUploadItem( UploadType type ) : KPIM::GroupwareUploadItem( type ) {}
- QDomDocument mDavData;
+ TQDomDocument mDavData;
};
class ExchangeAddressBookAdaptor : public DavAddressBookAdaptor
@@ -57,9 +57,9 @@ class ExchangeAddressBookAdaptor : public DavAddressBookAdaptor
void customAdaptDownloadUrl( KURL &url );
void customAdaptUploadUrl( KURL &url );
- QString mimeType() const { return "message/rfc822"; }
- QCString identifier() const { return "KABCResourceExchange"; }
- QString defaultNewItemName( KPIM::GroupwareUploadItem *item );
+ TQString mimeType() const { return "message/rfc822"; }
+ TQCString identifier() const { return "KABCResourceExchange"; }
+ TQString defaultNewItemName( KPIM::GroupwareUploadItem *item );
long flags() const { return GWResBatchDelete; }
@@ -77,9 +77,9 @@ class ExchangeAddressBookAdaptor : public DavAddressBookAdaptor
// Interpreting Jobs
- bool interpretListItemsJob( KIO::Job *job, const QString &jobData )
+ bool interpretListItemsJob( KIO::Job *job, const TQString &jobData )
{ return ExchangeGlobals::interpretListItemsJob( this, job, jobData ); }
- bool interpretDownloadItemsJob( KIO::Job *job, const QString &jobData )
+ bool interpretDownloadItemsJob( KIO::Job *job, const TQString &jobData )
{ return ExchangeGlobals::interpretAddressBookDownloadItemsJob( this, job, jobData ); }
@@ -91,9 +91,9 @@ class ExchangeAddressBookAdaptor : public DavAddressBookAdaptor
- bool getFolderHasSubs( const QDomNode &folderNode )
+ bool getFolderHasSubs( const TQDomNode &folderNode )
{ return ExchangeGlobals::getFolderHasSubs( folderNode ); }
- KPIM::FolderLister::ContentType getContentType( const QDomNode &folderNode )
+ KPIM::FolderLister::ContentType getContentType( const TQDomNode &folderNode )
{ return ExchangeGlobals::getContentType( folderNode ); }
};
diff --git a/kresources/newexchange/exchangecalendaradaptor.cpp b/kresources/newexchange/exchangecalendaradaptor.cpp
index 254eb4da..ceec4412 100644
--- a/kresources/newexchange/exchangecalendaradaptor.cpp
+++ b/kresources/newexchange/exchangecalendaradaptor.cpp
@@ -98,9 +98,9 @@ void ExchangeCalendarAdaptor::customAdaptUploadUrl( KURL &url )
/* Removing items: old version of the exchange resource: If the event is part
of a sequence of recurring event, we need to delete the master!
-void ExchangeDelete::findUidSingleMaster( QString const& uid )
+void ExchangeDelete::findUidSingleMaster( TQString const& uid )
{
- QString query =
+ TQString query =
"SELECT \"DAV:href\", \"urn:schemas:calendar:uid\"\r\n"
"FROM Scope('shallow traversal of \"\"')\r\n"
"WHERE \"urn:schemas:calendar:uid\" = '" + uid + "'\r\n"
@@ -109,15 +109,15 @@ void ExchangeDelete::findUidSingleMaster( QString const& uid )
KIO::DavJob* job = KIO::davSearch( mAccount->calendarURL(), "DAV:", "sql", query, false );
job->setWindow( mWindow );
- connect(job, SIGNAL(result( KIO::Job * )), this, SLOT(slotFindUidResult(KIO::Job *)));
+ connect(job, TQT_SIGNAL(result( KIO::Job * )), this, TQT_SLOT(slotFindUidResult(KIO::Job *)));
}
*/
-QString ExchangeCalendarAdaptor::defaultNewItemName( KPIM::GroupwareUploadItem *item ) {
+TQString ExchangeCalendarAdaptor::defaultNewItemName( KPIM::GroupwareUploadItem *item ) {
if ( item ) return item->uid()+".EML";
- else return QString::null;
+ else return TQString::null;
}
KPIM::GroupwareUploadItem *ExchangeCalendarAdaptor::newUploadItem( KCal::Incidence*it,
@@ -126,19 +126,19 @@ KPIM::GroupwareUploadItem *ExchangeCalendarAdaptor::newUploadItem( KCal::Inciden
return new ExchangeCalendarUploadItem( this, it, type );
}
-bool ExchangeCalendarAdaptor::interpretUploadJob( KIO::Job *job, const QString &/*jobData*/ )
+bool ExchangeCalendarAdaptor::interpretUploadJob( KIO::Job *job, const TQString &/*jobData*/ )
{
kdDebug(7000) << "ExchangeCalendarAdaptor::interpretUploadJob " << endl;
KIO::DavJob *davjob = dynamic_cast<KIO::DavJob*>(job);
bool error = job->error();
- const QString err = job->errorString();
+ const TQString err = job->errorString();
if ( davjob ) {
if ( error ) {
emit itemUploadError( davjob->url(), err );
return false;
} else {
- QDomDocument doc( davjob->response() );
+ TQDomDocument doc( davjob->response() );
// TODO: extract the href and the items that got a 404. If there's
// something important among them, issue the "usual" not-all-settings-uploaded
// warning to the user.
@@ -153,20 +153,20 @@ bool ExchangeCalendarAdaptor::interpretUploadJob( KIO::Job *job, const QString &
}
}
-bool ExchangeCalendarAdaptor::interpretUploadNewJob( KIO::Job *job, const QString &/*jobData*/ )
+bool ExchangeCalendarAdaptor::interpretUploadNewJob( KIO::Job *job, const TQString &/*jobData*/ )
{
// TODO: How does the incidence mapper know the old/new ids???
kdDebug(7000) << "ExchangeCalendarAdaptor::interpretUploadNewJob " << endl;
KIO::DavJob *davjob = dynamic_cast<KIO::DavJob*>(job);
bool error = job->error();
- const QString err = job->errorString();
+ const TQString err = job->errorString();
if ( davjob ) {
if ( error ) {
emit itemUploadNewError( idMapper()->localId( davjob->url().path() ), err );
return false;
} else {
- QDomDocument doc( davjob->response() );
+ TQDomDocument doc( davjob->response() );
// TODO: extract the href and the items that got a 404. If there's
// something important among them, issue the "usual" not-all-settings-uploaded
// warning to the user.
diff --git a/kresources/newexchange/exchangecalendaradaptor.h b/kresources/newexchange/exchangecalendaradaptor.h
index 7e772302..08bad45f 100644
--- a/kresources/newexchange/exchangecalendaradaptor.h
+++ b/kresources/newexchange/exchangecalendaradaptor.h
@@ -27,7 +27,7 @@
#include <groupwareresourcejob.h>
#include <davcalendaradaptor.h>
#include <kurl.h>
-#include <qdom.h>
+#include <tqdom.h>
namespace KCal {
@@ -45,7 +45,7 @@ class ExchangeCalendarUploadItem : public KPIM::GroupwareUploadItem
protected:
ExchangeCalendarUploadItem( UploadType type ) : KPIM::GroupwareUploadItem( type ) {}
- QDomDocument mDavData;
+ TQDomDocument mDavData;
};
class ExchangeCalendarAdaptor : public DavCalendarAdaptor
@@ -55,9 +55,9 @@ class ExchangeCalendarAdaptor : public DavCalendarAdaptor
void customAdaptDownloadUrl( KURL &url );
void customAdaptUploadUrl( KURL &url );
- QString mimeType() const { return "message/rfc822"; }
- QCString identifier() const { return "KCalResourceExchange"; }
- QString defaultNewItemName( KPIM::GroupwareUploadItem *item );
+ TQString mimeType() const { return "message/rfc822"; }
+ TQCString identifier() const { return "KCalResourceExchange"; }
+ TQString defaultNewItemName( KPIM::GroupwareUploadItem *item );
long flags() const { return GWResBatchDelete; }
@@ -74,12 +74,12 @@ class ExchangeCalendarAdaptor : public DavCalendarAdaptor
// Interpreting Jobs
- bool interpretListItemsJob( KIO::Job *job, const QString &jobData )
+ bool interpretListItemsJob( KIO::Job *job, const TQString &jobData )
{ return ExchangeGlobals::interpretListItemsJob( this, job, jobData ); }
- bool interpretDownloadItemsJob( KIO::Job *job, const QString &jobData )
+ bool interpretDownloadItemsJob( KIO::Job *job, const TQString &jobData )
{ return ExchangeGlobals::interpretCalendarDownloadItemsJob( this, job, jobData ); }
- bool interpretUploadJob( KIO::Job *job, const QString &/*jobData*/ );
- bool interpretUploadNewJob( KIO::Job *job, const QString &/*jobData*/ );
+ bool interpretUploadJob( KIO::Job *job, const TQString &/*jobData*/ );
+ bool interpretUploadNewJob( KIO::Job *job, const TQString &/*jobData*/ );
@@ -88,9 +88,9 @@ class ExchangeCalendarAdaptor : public DavCalendarAdaptor
- bool getFolderHasSubs( const QDomNode &folderNode )
+ bool getFolderHasSubs( const TQDomNode &folderNode )
{ return ExchangeGlobals::getFolderHasSubs( folderNode ); }
- KPIM::FolderLister::ContentType getContentType( const QDomNode &folderNode )
+ KPIM::FolderLister::ContentType getContentType( const TQDomNode &folderNode )
{ return ExchangeGlobals::getContentType( folderNode ); }
};
diff --git a/kresources/newexchange/exchangeconvertercalendar.cpp b/kresources/newexchange/exchangeconvertercalendar.cpp
index bc0481da..be32291b 100644
--- a/kresources/newexchange/exchangeconvertercalendar.cpp
+++ b/kresources/newexchange/exchangeconvertercalendar.cpp
@@ -56,7 +56,7 @@ ExchangeConverterCalendar::ExchangeConverterCalendar()
{
}
-void ExchangeConverterCalendar::setTimeZone( const QString &id )
+void ExchangeConverterCalendar::setTimeZone( const TQString &id )
{
// kdDebug() << "Setting timezone to: " << id << endl;
mFormat.setTimeZone( id, true );
@@ -75,7 +75,7 @@ void ExchangeConverterCalendar::setTimeZone( const QString &id )
#define property( prop ) \
WebdavHandler::addElement( doc, root, prop )
-void ExchangeConverterCalendar::createRequestIncidence( QDomDocument &doc, QDomElement &root )
+void ExchangeConverterCalendar::createRequestIncidence( TQDomDocument &doc, TQDomElement &root )
{
propertyDAV( "contentclass" );
propertyDAV( "getcontenttype" );
@@ -98,10 +98,10 @@ void ExchangeConverterCalendar::createRequestIncidence( QDomDocument &doc, QDomE
propertyHTTPMail( "hasattachment" );
}
-void ExchangeConverterCalendar::createRequestAppointment( QDomDocument &doc, QDomElement &root )
+void ExchangeConverterCalendar::createRequestAppointment( TQDomDocument &doc, TQDomElement &root )
{
createRequestIncidence( doc, root );
- QDomAttr att_c = doc.createAttribute( "xmlns:c" );
+ TQDomAttr att_c = doc.createAttribute( "xmlns:c" );
att_c.setValue( "urn:schemas:calendar:" );
doc.documentElement().setAttributeNode( att_c );
propertyCalendar( "uid" );
@@ -132,17 +132,17 @@ void ExchangeConverterCalendar::createRequestAppointment( QDomDocument &doc, QDo
#define propertyTask2( prop ) \
WebdavHandler::addElement( doc, props, "t2:"prop )
-void ExchangeConverterCalendar::createRequestTask( QDomDocument &doc, QDomElement &props )
+void ExchangeConverterCalendar::createRequestTask( TQDomDocument &doc, TQDomElement &props )
{
createRequestIncidence( doc, props );
- QDomElement root = doc.documentElement();
+ TQDomElement root = doc.documentElement();
- QDomAttr att_t1 = doc.createAttribute( "xmlns:t1" );
+ TQDomAttr att_t1 = doc.createAttribute( "xmlns:t1" );
att_t1.setValue( TaskNamespace1 );
root.setAttributeNode( att_t1 );
- QDomAttr att_t2 = doc.createAttribute( "xmlns:t2" );
+ TQDomAttr att_t2 = doc.createAttribute( "xmlns:t2" );
att_t2.setValue( TaskNamespace2 );
root.setAttributeNode( att_t2 );
@@ -169,7 +169,7 @@ void ExchangeConverterCalendar::createRequestTask( QDomDocument &doc, QDomElemen
#undef propertyTask1
#undef propertyTask2
-void ExchangeConverterCalendar::createRequestJournal( QDomDocument &doc, QDomElement &root )
+void ExchangeConverterCalendar::createRequestJournal( TQDomDocument &doc, TQDomElement &root )
{
createRequestIncidence( doc, root );
propertyDAV( "uid" );
@@ -183,21 +183,21 @@ void ExchangeConverterCalendar::createRequestJournal( QDomDocument &doc, QDomEle
#undef propertyMailHeader
#undef property
-bool ExchangeConverterCalendar::readTZ( const QDomElement &node, Incidence */*incidence*/ )
+bool ExchangeConverterCalendar::readTZ( const TQDomElement &node, Incidence */*incidence*/ )
{
- QString timezoneid;
+ TQString timezoneid;
if ( WebdavHandler::extractString( node, "timezoneid", timezoneid ) ) {
// kdDebug() << "DEBUG: timezoneid = " << timezoneid << endl;
}
- QString timezone;
+ TQString timezone;
if ( WebdavHandler::extractString( node, "timezone", timezone ) ) {
// kdDebug() << "DEBUG: timezone = " << timezone << endl;
}
// TODO:
/* // mFormat is used for parsing recurrence rules.
- QString localTimeZoneId;
+ TQString localTimeZoneId;
if ( mCalendar ) {
mFormat.setTimeZone( mCalendar->timeZoneId(), !mCalendar->isLocalTime() );
localTimeZoneId = mCalendar->timeZoneId();
@@ -209,14 +209,14 @@ bool ExchangeConverterCalendar::readTZ( const QDomElement &node, Incidence */*in
return true;
}
-bool ExchangeConverterCalendar::readIncidence( const QDomElement &node, Incidence *incidence )
+bool ExchangeConverterCalendar::readIncidence( const TQDomElement &node, Incidence *incidence )
{
kdDebug()<<"ExchangeConverterCalendar::readIncidencd"<<endl;
- QDateTime tmpdt;
+ TQDateTime tmpdt;
bool tmpbool;
- QString tmpstr;
+ TQString tmpstr;
long tmplng;
- QStringList tmplst;
+ TQStringList tmplst;
readTZ( node, incidence );
@@ -264,9 +264,9 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidencd"<<endl;
if ( WebdavHandler::extractString( node, "from", tmpstr ) )
incidence->setOrganizer( tmpstr );
if ( WebdavHandler::extractString( node, "to", tmpstr ) ) {
- QStringList atts( KPIM::splitEmailAddrList( tmpstr ) );
- for ( QStringList::Iterator it = atts.begin(); it != atts.end(); ++it ) {
- QString name, email;
+ TQStringList atts( KPIM::splitEmailAddrList( tmpstr ) );
+ for ( TQStringList::Iterator it = atts.begin(); it != atts.end(); ++it ) {
+ TQString name, email;
KPIM::getNameAndMail( *it, name, email );
Attendee *att = new Attendee( name, email );
att->setRole( KCal::Attendee::ReqParticipant );
@@ -279,9 +279,9 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidencd"<<endl;
}
}
if ( WebdavHandler::extractString( node, "cc", tmpstr ) ) {
- QStringList atts( KPIM::splitEmailAddrList( tmpstr ) );
- for ( QStringList::Iterator it = atts.begin(); it != atts.end(); ++it ) {
- QString name, email;
+ TQStringList atts( KPIM::splitEmailAddrList( tmpstr ) );
+ for ( TQStringList::Iterator it = atts.begin(); it != atts.end(); ++it ) {
+ TQString name, email;
KPIM::getNameAndMail( *it, name, email );
Attendee *att = new Attendee( name, email );
att->setRole( KCal::Attendee::OptParticipant );
@@ -298,10 +298,10 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidencd"<<endl;
}
/* FIXME: Handle recurrences
-void ExchangeDownload::handleRecurrence( QString uid )
+void ExchangeDownload::handleRecurrence( TQString uid )
{
// kdDebug() << "Handling recurrence info for uid=" << uid << endl;
- QString query =
+ TQString query =
"SELECT \"DAV:href\", \"urn:schemas:calendar:instancetype\"\r\n"
"FROM Scope('shallow traversal of \"\"')\r\n"
"WHERE \"urn:schemas:calendar:uid\" = '" + uid + "'\r\n"
@@ -314,18 +314,18 @@ void ExchangeDownload::handleRecurrence( QString uid )
query, false );
KIO::Scheduler::scheduleJob( job );
job->setWindow( mWindow );
- connect( job, SIGNAL( result( KIO::Job * ) ),
- SLOT( slotMasterResult( KIO::Job * ) ) );
+ connect( job, TQT_SIGNAL( result( KIO::Job * ) ),
+ TQT_SLOT( slotMasterResult( KIO::Job * ) ) );
}
*/
-bool ExchangeConverterCalendar::readEvent( const QDomElement &node, Event *event )
+bool ExchangeConverterCalendar::readEvent( const TQDomElement &node, Event *event )
{
if ( !readIncidence( node, event ) ) return false;
kdDebug()<<"ExchangeConverterCalendar::readEvent"<<endl;
- QDateTime tmpdt;
- QString tmpstr;
+ TQDateTime tmpdt;
+ TQString tmpstr;
long tmplng;
bool tmpbool;
@@ -405,19 +405,19 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidence: ERROR: No UID given"<<endl
}
}
- QStringList tmplst;
+ TQStringList tmplst;
if ( WebdavHandler::extractStringList( node, "exdate", tmplst ) ) {
- QStringList::Iterator it = tmplst.begin();
+ TQStringList::Iterator it = tmplst.begin();
KCal::DateList exdates;
for ( ; it != tmplst.end(); ++it ) {
- exdates.append( /*utcAsZone(*/ QDateTime::fromString( *it, Qt::ISODate )/*,
+ exdates.append( /*utcAsZone(*/ TQDateTime::fromString( *it, Qt::ISODate )/*,
localTimeZoneId )*/.date() );
}
event->recurrence()->setExDates( exdates );
}
// FIXME: use rdate and exrule!
/* FIXME: Recurring events, they are split up
- QDomElement instancetypeElement = prop.namedItem( "instancetype" ).toElement();
+ TQDomElement instancetypeElement = prop.namedItem( "instancetype" ).toElement();
if ( instancetypeElement.isNull() ) {
kdError() << "Error: no instance type in Exchange server reply" << endl;
continue;
@@ -426,12 +426,12 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidence: ERROR: No UID given"<<endl
//kdDebug() << "Instance type: " << instanceType << endl;
if ( recurrence && instanceType > 0 ) {
- QDomElement uidElement = prop.namedItem( "uid" ).toElement();
+ TQDomElement uidElement = prop.namedItem( "uid" ).toElement();
if ( uidElement.isNull() ) {
kdError() << "Error: no uid in Exchange server reply" << endl;
continue;
}
- QString uid = uidElement.text();
+ TQString uid = uidElement.text();
if ( ! m_uids.contains( uid ) ) {
m_uids[uid] = 1;
handleRecurrence(uid);
@@ -448,7 +448,7 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidence: ERROR: No UID given"<<endl
return true;
}
-bool ExchangeConverterCalendar::readTodo( const QDomElement &node, Todo *todo )
+bool ExchangeConverterCalendar::readTodo( const TQDomElement &node, Todo *todo )
{
if ( !readIncidence( node, todo ) ) return false;
kdDebug()<<"ExchangeConverterCalendar::readTodo"<<endl;
@@ -456,11 +456,11 @@ kdDebug()<<"ExchangeConverterCalendar::readTodo"<<endl;
// FIXME: Retrieve time zone: "timezone"
// FIXME: What to with TaskProp_Owner and TaskProp_ContactNames?
- QDateTime tmpdt;
+ TQDateTime tmpdt;
float tmpfloat;
long tmplong;
bool tmpbool;
- QString tmpstr;
+ TQString tmpstr;
// The UID is absolutely required!
// FIXME: Which field shall be used as uid???
@@ -503,12 +503,12 @@ kdDebug()<<"ExchangeConverterCalendar::readIncidence: ERROR: No UID given"<<endl
return true;
}
-bool ExchangeConverterCalendar::readJournal( const QDomElement &node, Journal *journal )
+bool ExchangeConverterCalendar::readJournal( const TQDomElement &node, Journal *journal )
{
if ( !readIncidence( node, journal ) ) return false;
kdDebug()<<"ExchangeConverterCalendar::readJournal"<<endl;
- QDateTime tmpdt;
- QString tmpstr;
+ TQDateTime tmpdt;
+ TQString tmpstr;
// The UID is absolutely required!
// FIXME: Which field shall be used as UID?
if ( WebdavHandler::extractString( node, "uid", tmpstr ) ) {
@@ -528,13 +528,13 @@ kdDebug()<<"ExchangeConverterCalendar::readJournal: ERROR: No UID given"<<endl;
return true;
}
-Incidence::List ExchangeConverterCalendar::parseWebDAV( const QDomDocument& davdata )
+Incidence::List ExchangeConverterCalendar::parseWebDAV( const TQDomDocument& davdata )
{
- QDomElement prop = davdata.documentElement().namedItem( "response" )
+ TQDomElement prop = davdata.documentElement().namedItem( "response" )
.namedItem( "propstat" ).namedItem( "prop" ).toElement();
if ( prop.isNull() ) return Incidence::List();
- QString contentclass;
+ TQString contentclass;
bool success = WebdavHandler::extractString( prop, "contentclass", contentclass );
if ( !success ) return Incidence::List();
@@ -581,7 +581,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
{
public:
createWebDAVVisitor() : Visitor() {}
- bool act( QDomDocument doc, QDomElement el, IncidenceBase *incidence, const QString &timeZoneId )
+ bool act( TQDomDocument doc, TQDomElement el, IncidenceBase *incidence, const TQString &timeZoneId )
{
mDoc = doc;
mElement = el;
@@ -589,15 +589,15 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
return incidence->accept( *this );
}
protected:
- void addBoolProp( QDomElement &el ) { el.setAttribute( "b:dt", "boolean" ); }
- void addDateProp( QDomElement &el ) { el.setAttribute( "b:dt", "dateTime.tz" ); }
- void addFloatProp( QDomElement &el ) { el.setAttribute( "b:dt", "float" ); }
- void addIntProp( QDomElement &el ) { el.setAttribute( "b:dt", "int" ); }
- QString timePropString( const QDateTime &dt ) { return dt.toString( Qt::ISODate )+"Z"; }
+ void addBoolProp( TQDomElement &el ) { el.setAttribute( "b:dt", "boolean" ); }
+ void addDateProp( TQDomElement &el ) { el.setAttribute( "b:dt", "dateTime.tz" ); }
+ void addFloatProp( TQDomElement &el ) { el.setAttribute( "b:dt", "float" ); }
+ void addIntProp( TQDomElement &el ) { el.setAttribute( "b:dt", "int" ); }
+ TQString timePropString( const TQDateTime &dt ) { return dt.toString( Qt::ISODate )+"Z"; }
bool visitIncidence( Incidence *incidence )
{
- QString tmpstr;
+ TQString tmpstr;
domDavProperty( "isreadonly", (incidence->isReadOnly())?"1":"0" );
// FIXME: scheduling ID
// domProperty( "http://schemas.microsoft.com/repl/", "repl-uid", ??? );
@@ -607,7 +607,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
// domHTTPMailProperty( "date", ??? ); // timestamp not available in libkcal
// domDavProperty( "comment", incidence->comments() ); // libkcal has a QStringlist, not one string
// domProperty( "urn:schemas-microsoft-com:office:office", "Keywords", ??? ); // It's a <v>entyr1</v><v>entry2</v> String list!
- tmpstr = QString::null;
+ tmpstr = TQString::null;
switch ( incidence->secrecy() ) {
case KCal::Incidence::SecrecyPublic: tmpstr = "0"; break;
case KCal::Incidence::SecrecyPrivate: tmpstr = "2"; break;
@@ -617,14 +617,14 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
if ( !tmpstr.isEmpty() )
domProperty( "http://schemas.microsoft.com/exchange/", "sensitivity", tmpstr );
- domHTTPMailProperty( "priority", QString::number(incidence->priority()) );
+ domHTTPMailProperty( "priority", TQString::number(incidence->priority()) );
domMailHeaderProperty( "from", incidence->organizer().fullName() );
// Attendees:
- tmpstr = QString::null;
- QStringList reqattnames;
- QStringList optattnames;
+ tmpstr = TQString::null;
+ TQStringList reqattnames;
+ TQStringList optattnames;
Attendee::List atts = incidence->attendees();
for ( Attendee::List::Iterator it = atts.begin(); it != atts.end(); ++it ) {
switch ( (*it)->role() ) {
@@ -652,7 +652,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
{
if ( !visitIncidence(event) ) return false;
- QDomAttr att_c = mDoc.createAttribute( "xmlns:c" );
+ TQDomAttr att_c = mDoc.createAttribute( "xmlns:c" );
att_c.setValue( "urn:schemas:calendar:" );
mDoc.documentElement().setAttributeNode( att_c );
@@ -660,7 +660,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
domProperty( "http://schemas.microsoft.com/exchange/",
"outlookmessageclass", "IPM.Appointment" );
domCalendarProperty( "uid", event->uid() );
- QDomElement el = domCalendarProperty( "created", timePropString( WebdavHandler::zoneAsUtc( event->created(), mTimeZoneId ) ) );
+ TQDomElement el = domCalendarProperty( "created", timePropString( WebdavHandler::zoneAsUtc( event->created(), mTimeZoneId ) ) );
addDateProp( el );
el = domCalendarProperty( "lastmodified", timePropString( WebdavHandler::zoneAsUtc( event->lastModified(), mTimeZoneId ) ) );
addDateProp( el );
@@ -668,7 +668,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
// FIXME: domCalendarProperty( "sequence", event->sequence() );
domCalendarProperty( "location", event->location() );
- QString tmpstr( QString::null );
+ TQString tmpstr( TQString::null );
switch ( event->transparency() ) {
case KCal::Event::Transparent: tmpstr = "FREE"; break;
case KCal::Event::Opaque: tmpstr = "BUSY"; break;
@@ -684,7 +684,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
el = domCalendarProperty( "dtend", timePropString( WebdavHandler::zoneAsUtc( event->dtEnd(), mTimeZoneId ) ) );
addDateProp( el );
} else {
- domCalendarProperty( "duration", QString::number( event->duration() ) );
+ domCalendarProperty( "duration", TQString::number( event->duration() ) );
}
// FIXME: Convert the recurrence rule to a string:
if ( event->doesRecur() ) {
@@ -703,7 +703,7 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
Alarm::List alarms = event->alarms();
for( it = alarms.begin(); it != alarms.end(); ++it ) {
if ((*it)->hasStartOffset()) {
- domCalendarProperty( "reminderoffset", QString::number( (*it)->startOffset().asSeconds() * -1 ) );
+ domCalendarProperty( "reminderoffset", TQString::number( (*it)->startOffset().asSeconds() * -1 ) );
} else {
kdDebug() << "ExchangeConverterCalendar::createWebDAVVisitor: Alarm type not supported\n";
}
@@ -715,11 +715,11 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
{
if ( !visitIncidence(todo) ) return false;
- QDomAttr att_t1 = mDoc.createAttribute( "xmlns:t1" );
+ TQDomAttr att_t1 = mDoc.createAttribute( "xmlns:t1" );
att_t1.setValue( TaskNamespace1 );
mDoc.documentElement().setAttributeNode( att_t1 );
- QDomAttr att_t2 = mDoc.createAttribute( "xmlns:t2" );
+ TQDomAttr att_t2 = mDoc.createAttribute( "xmlns:t2" );
att_t2.setValue( TaskNamespace2 );
mDoc.documentElement().setAttributeNode( att_t2 );
@@ -765,9 +765,9 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
}
protected:
- QDomDocument mDoc;
- QDomElement mElement;
- QString mTimeZoneId;
+ TQDomDocument mDoc;
+ TQDomElement mElement;
+ TQString mTimeZoneId;
};
// Prefixes for the namespaces:
@@ -780,27 +780,27 @@ class ExchangeConverterCalendar::createWebDAVVisitor : public IncidenceBase::Vis
// o... office
//
-QDomDocument ExchangeConverterCalendar::createWebDAV( Incidence *incidence )
+TQDomDocument ExchangeConverterCalendar::createWebDAV( Incidence *incidence )
{
// TODO
- QDomDocument doc;
- QDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propertyupdate" );
- QDomElement set = WebdavHandler::addElement( doc, root, "d:set" );
- QDomElement prop = WebdavHandler::addElement( doc, set, "d:prop" );
+ TQDomDocument doc;
+ TQDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propertyupdate" );
+ TQDomElement set = WebdavHandler::addElement( doc, root, "d:set" );
+ TQDomElement prop = WebdavHandler::addElement( doc, set, "d:prop" );
- QDomAttr att_b = doc.createAttribute( "xmlns:b" );
+ TQDomAttr att_b = doc.createAttribute( "xmlns:b" );
att_b.setValue( "urn:schemas-microsoft-com:datatypes" );
root.setAttributeNode( att_b );
- QDomAttr att_h = doc.createAttribute( "xmlns:h" );
+ TQDomAttr att_h = doc.createAttribute( "xmlns:h" );
att_h.setValue( "urn:schemas:mailheader:" );
root.setAttributeNode( att_h );
- QDomAttr att_m = doc.createAttribute( "xmlns:m" );
+ TQDomAttr att_m = doc.createAttribute( "xmlns:m" );
att_m.setValue( "urn:schemas:httpmail:" );
root.setAttributeNode( att_m );
-// QDomAttr att1 = doc.createAttributeNS( "do:whatever:you:like", "x:attname");
+// TQDomAttr att1 = doc.createAttributeNS( "do:whatever:you:like", "x:attname");
// att1.setValue( "value" );
// prop.setAttributeNodeNS( att1 );
// root.setAttributeNodeNS( att1 );
diff --git a/kresources/newexchange/exchangeconvertercalendar.h b/kresources/newexchange/exchangeconvertercalendar.h
index 346b2a95..a561d0cd 100644
--- a/kresources/newexchange/exchangeconvertercalendar.h
+++ b/kresources/newexchange/exchangeconvertercalendar.h
@@ -21,8 +21,8 @@
#ifndef KCal_EXCHANGECONVERTERCONTACT_H
#define KCal_EXCHANGECONVERTERCONTACT_H
-#include <qstring.h>
-#include <qdom.h>
+#include <tqstring.h>
+#include <tqdom.h>
#include <libkcal/incidence.h>
#include <libkcal/icalformat.h>
@@ -36,23 +36,23 @@ class ExchangeConverterCalendar
ExchangeConverterCalendar();
- void setTimeZone( const QString &id );
+ void setTimeZone( const TQString &id );
- static void createRequestAppointment( QDomDocument &doc, QDomElement &root );
- static void createRequestTask( QDomDocument &doc, QDomElement &root );
- static void createRequestJournal( QDomDocument &doc, QDomElement &root );
+ static void createRequestAppointment( TQDomDocument &doc, TQDomElement &root );
+ static void createRequestTask( TQDomDocument &doc, TQDomElement &root );
+ static void createRequestJournal( TQDomDocument &doc, TQDomElement &root );
- QDomDocument createWebDAV( Incidence *incidence );
+ TQDomDocument createWebDAV( Incidence *incidence );
- Incidence::List parseWebDAV( const QDomDocument& davdata );
- bool readIncidence( const QDomElement &node, Incidence *incidence );
+ Incidence::List parseWebDAV( const TQDomDocument& davdata );
+ bool readIncidence( const TQDomElement &node, Incidence *incidence );
protected:
- static void createRequestIncidence( QDomDocument &doc, QDomElement &root );
- bool readEvent( const QDomElement &node, Event *event );
- bool readTodo( const QDomElement &node, Todo *todo );
- bool readJournal( const QDomElement &node, Journal *journal );
- bool readTZ( const QDomElement &node, Incidence *incidence );
+ static void createRequestIncidence( TQDomDocument &doc, TQDomElement &root );
+ bool readEvent( const TQDomElement &node, Event *event );
+ bool readTodo( const TQDomElement &node, Todo *todo );
+ bool readJournal( const TQDomElement &node, Journal *journal );
+ bool readTZ( const TQDomElement &node, Incidence *incidence );
KCal::ICalFormat mFormat;
class createWebDAVVisitor;
diff --git a/kresources/newexchange/exchangeconvertercontact.h b/kresources/newexchange/exchangeconvertercontact.h
index 45ee7c7c..191abccb 100644
--- a/kresources/newexchange/exchangeconvertercontact.h
+++ b/kresources/newexchange/exchangeconvertercontact.h
@@ -21,8 +21,8 @@
#ifndef KABC_EXCHANGECONVERTERCONTACT_H
#define KABC_EXCHANGECONVERTERCONTACT_H
-#include <qstring.h>
-#include <qdom.h>
+#include <tqstring.h>
+#include <tqdom.h>
#include <kabc/addressee.h>
@@ -34,18 +34,18 @@ class ExchangeConverterContact
ExchangeConverterContact();
- static void createRequest( QDomDocument &doc, QDomElement &root );
+ static void createRequest( TQDomDocument &doc, TQDomElement &root );
- QDomDocument createWebDAV( Addressee addr );
+ TQDomDocument createWebDAV( Addressee addr );
- Addressee::List parseWebDAV( const QDomDocument& davdata );
- bool readAddressee( const QDomElement &node, Addressee &addressee );
+ Addressee::List parseWebDAV( const TQDomDocument& davdata );
+ bool readAddressee( const TQDomElement &node, Addressee &addressee );
protected:
- bool extractAddress( const QDomElement &node, Addressee &addressee, int type,
- const QString &street, const QString &pobox, const QString &location,
- const QString &postalcode, const QString &state, const QString &country,
- const QString &countycode );
+ bool extractAddress( const TQDomElement &node, Addressee &addressee, int type,
+ const TQString &street, const TQString &pobox, const TQString &location,
+ const TQString &postalcode, const TQString &state, const TQString &country,
+ const TQString &countycode );
};
}
diff --git a/kresources/newexchange/exchangeglobals.cpp b/kresources/newexchange/exchangeglobals.cpp
index 7cca837d..54405166 100644
--- a/kresources/newexchange/exchangeglobals.cpp
+++ b/kresources/newexchange/exchangeglobals.cpp
@@ -33,14 +33,14 @@
#include <kio/davjob.h>
#include <kdebug.h>
-KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const QDomElement &prop )
+KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const TQDomElement &prop )
{
- const QString &contentclass = prop.namedItem("contentclass").toElement().text();
+ const TQString &contentclass = prop.namedItem("contentclass").toElement().text();
kdDebug()<<"contentclass: "<<contentclass<<endl;
return getContentType( contentclass );
}
-KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const QString &contentclass )
+KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const TQString &contentclass )
{
if ( contentclass == "urn:content-classes:appointment" )
return KPIM::FolderLister::Event;
@@ -54,15 +54,15 @@ KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const QString &
}
-KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const QDomNode &folderNode )
+KPIM::FolderLister::ContentType ExchangeGlobals::getContentType( const TQDomNode &folderNode )
{
kdDebug()<<"ExchangeGlobals::getContentType(...)"<<endl;
- QDomNode n4;
+ TQDomNode n4;
for( n4 = folderNode.firstChild(); !n4.isNull(); n4 = n4.nextSibling() ) {
- QDomElement e = n4.toElement();
+ TQDomElement e = n4.toElement();
if ( e.tagName() == "contentclass" ) {
- QString contentclass( e.text() );
+ TQString contentclass( e.text() );
if ( contentclass == "urn:content-classes:contactfolder" )
return KPIM::FolderLister::Contact;
if ( contentclass == "urn:content-classes:calendarfolder" )
@@ -78,9 +78,9 @@ kdDebug()<<"ExchangeGlobals::getContentType(...)"<<endl;
return KPIM::FolderLister::Unknown;
}
-bool ExchangeGlobals::getFolderHasSubs( const QDomNode &folderNode )
+bool ExchangeGlobals::getFolderHasSubs( const TQDomNode &folderNode )
{
- QString hassubs = folderNode.namedItem( "hassubs" ).toElement().text();
+ TQString hassubs = folderNode.namedItem( "hassubs" ).toElement().text();
return hassubs == "1";
}
@@ -89,9 +89,9 @@ bool ExchangeGlobals::getFolderHasSubs( const QDomNode &folderNode )
KIO::Job *ExchangeGlobals::createListFoldersJob( const KURL &url )
{
- QDomDocument doc;
- QDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
- QDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
+ TQDomDocument doc;
+ TQDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
+ TQDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
WebdavHandler::addElement( doc, prop, "d:displayname" );
WebdavHandler::addElement( doc, prop, "d:contentclass" );
WebdavHandler::addElement( doc, prop, "d:hassubs" );
@@ -103,9 +103,9 @@ KIO::Job *ExchangeGlobals::createListFoldersJob( const KURL &url )
KIO::TransferJob *ExchangeGlobals::createListItemsJob( const KURL &url )
{
- QDomDocument doc;
- QDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
- QDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
+ TQDomDocument doc;
+ TQDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
+ TQDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
WebdavHandler::addElement( doc, prop, "d:getetag" );
WebdavHandler::addElement( doc, prop, "d:contentclass" );
kdDebug(5800) << "props = "<< doc.toString() << endl;
@@ -125,14 +125,14 @@ kdDebug() << "Person=" << KPIM::FolderLister::Contact << ", "
<< "Message=" << KPIM::FolderLister::Message << endl;
// Don't use an <allprop/> request!
- QDomDocument doc;
- QDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
- QDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
- QDomAttr att_h = doc.createAttribute( "xmlns:h" );
+ TQDomDocument doc;
+ TQDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propfind" );
+ TQDomElement prop = WebdavHandler::addElement( doc, root, "d:prop" );
+ TQDomAttr att_h = doc.createAttribute( "xmlns:h" );
att_h.setValue( "urn:schemas:mailheader:" );
root.setAttributeNode( att_h );
- QDomAttr att_m = doc.createAttribute( "xmlns:m" );
+ TQDomAttr att_m = doc.createAttribute( "xmlns:m" );
att_m.setValue( "urn:schemas:httpmail:" );
root.setAttributeNode( att_m );
@@ -158,7 +158,7 @@ kdDebug() << "Person=" << KPIM::FolderLister::Contact << ", "
KURL authURL = url;
KIO::DavJob *job = KIO::davPropFind( authURL, doc, "0", false );
/* KURL httpurl( url );
- QString proto("http");
+ TQString proto("http");
httpurl.setProtocol( proto );
KIO::TransferJob *job = KIO::get(httpurl, false, false);
job->addMetaData("customHTTPHeader", "Translate: f");
@@ -170,7 +170,7 @@ kdDebug() << "Person=" << KPIM::FolderLister::Contact << ", "
KIO::Job *ExchangeGlobals::createRemoveJob( const KURL &uploadurl,
const KPIM::GroupwareUploadItem::List &deletedItems )
{
- QStringList urls;
+ TQStringList urls;
KPIM::GroupwareUploadItem::List::const_iterator it;
kdDebug() << " ExchangeGlobals::createRemoveJob: , URL="<<uploadurl.url()<<endl;
for ( it = deletedItems.begin(); it != deletedItems.end(); ++it ) {
@@ -192,7 +192,7 @@ KIO::Job *ExchangeGlobals::createRemoveJob( const KURL &uploadurl,
// it calls getContentType of the ExchangeGlobals class, instead of the one
// from OGoGlobals!!!!
bool ExchangeGlobals::interpretListItemsJob( KPIM::GroupwareDataAdaptor *adaptor,
- KIO::Job *job, const QString &/*jobData*/ )
+ KIO::Job *job, const TQString &/*jobData*/ )
{
kdDebug()<<"ExchangeGlobals::interpretListItemsJob"<<endl;
KIO::DavJob *davjob = dynamic_cast<KIO::DavJob *>(job);
@@ -200,28 +200,28 @@ kdDebug()<<"ExchangeGlobals::interpretListItemsJob"<<endl;
if ( !davjob ) {
return false;
}
- QDomDocument doc = davjob->response();
+ TQDomDocument doc = davjob->response();
kdDebug(7000) << " Doc: " << doc.toString() << endl;
kdDebug(7000) << " IdMapper: " << adaptor->idMapper()->asString() << endl;
- QDomElement docElem = doc.documentElement();
- QDomNode n = docElem.firstChild();
+ TQDomElement docElem = doc.documentElement();
+ TQDomNode n = docElem.firstChild();
while( !n.isNull() ) {
- QDomElement e = n.toElement(); // try to convert the node to an element.
+ TQDomElement e = n.toElement(); // try to convert the node to an element.
n = n.nextSibling();
if ( e.isNull() )
continue;
const KURL &entry( e.namedItem("href").toElement().text() );
- QDomElement propstat = e.namedItem("propstat").toElement();
+ TQDomElement propstat = e.namedItem("propstat").toElement();
if ( propstat.isNull() )
continue;
- QDomElement prop = propstat.namedItem( "prop" ).toElement();
+ TQDomElement prop = propstat.namedItem( "prop" ).toElement();
if ( prop.isNull() )
continue;
- QDomElement elem = prop.namedItem("getetag").toElement();
- const QString &newFingerprint = elem.text();
+ TQDomElement elem = prop.namedItem("getetag").toElement();
+ const TQString &newFingerprint = elem.text();
if ( elem.isNull() || newFingerprint.isEmpty() )
continue;
@@ -237,7 +237,7 @@ kdDebug()<<"ExchangeGlobals::interpretListItemsJob"<<endl;
bool ExchangeGlobals::interpretCalendarDownloadItemsJob( KCal::CalendarAdaptor *adaptor,
- KIO::Job *job, const QString &/*jobData*/ )
+ KIO::Job *job, const TQString &/*jobData*/ )
{
KIO::DavJob *davjob = dynamic_cast<KIO::DavJob*>(job);
if ( !davjob || !adaptor ) return false;
@@ -251,7 +251,7 @@ kdDebug() << "ExchangeGlobals::interpretCalendarDownloadItemsJob(): QDomDocument
bool res = false;
KCal::Incidence::List::Iterator it = incidences.begin();
for ( ; it != incidences.end(); ++it ) {
- QString fpr = (*it)->customProperty( "KDEPIM-Exchange-Resource", "fingerprint" );
+ TQString fpr = (*it)->customProperty( "KDEPIM-Exchange-Resource", "fingerprint" );
KURL href( (*it)->customProperty( "KDEPIM-Exchange-Resource", "href" ) );
adaptor->calendarItemDownloaded( (*it), (*it)->uid(), href, fpr, href.prettyURL() );
res = true;
@@ -261,7 +261,7 @@ kdDebug() << "ExchangeGlobals::interpretCalendarDownloadItemsJob(): QDomDocument
bool ExchangeGlobals::interpretAddressBookDownloadItemsJob(
- KABC::AddressBookAdaptor *adaptor, KIO::Job *job, const QString &/*jobData*/ )
+ KABC::AddressBookAdaptor *adaptor, KIO::Job *job, const TQString &/*jobData*/ )
{
KIO::DavJob *davjob = dynamic_cast<KIO::DavJob*>(job);
if ( !davjob || !adaptor ) return false;
@@ -274,7 +274,7 @@ kdDebug() << "ExchangeGlobals::interpretAddressBookDownloadItemsJob(): QDomDocum
bool res = false;
KABC::Addressee::List::Iterator it = addressees.begin();
for ( ; it != addressees.end(); ++it ) {
- QString fpr = (*it).custom( "KDEPIM-Exchange-Resource", "fingerprint" );
+ TQString fpr = (*it).custom( "KDEPIM-Exchange-Resource", "fingerprint" );
KURL href( (*it).custom( "KDEPIM-Exchange-Resource", "href" ) );
adaptor->addressbookItemDownloaded( (*it), (*it).uid(), href, fpr, href.prettyURL() );
res = true;
diff --git a/kresources/newexchange/exchangeglobals.h b/kresources/newexchange/exchangeglobals.h
index ba56830d..f8ad3317 100644
--- a/kresources/newexchange/exchangeglobals.h
+++ b/kresources/newexchange/exchangeglobals.h
@@ -23,7 +23,7 @@
#include <kurl.h>
#include <groupwareuploadjob.h>
-#include <qdom.h>
+#include <tqdom.h>
namespace KIO {
class Job;
@@ -45,10 +45,10 @@ class ExchangeGlobals
{
public:
ExchangeGlobals() {}
- static KPIM::FolderLister::ContentType getContentType( const QDomElement &prop );
- static KPIM::FolderLister::ContentType getContentType( const QString &contentclass );
- static KPIM::FolderLister::ContentType getContentType( const QDomNode &folderNode );
- static bool getFolderHasSubs( const QDomNode &folderNode );
+ static KPIM::FolderLister::ContentType getContentType( const TQDomElement &prop );
+ static KPIM::FolderLister::ContentType getContentType( const TQString &contentclass );
+ static KPIM::FolderLister::ContentType getContentType( const TQDomNode &folderNode );
+ static bool getFolderHasSubs( const TQDomNode &folderNode );
static KIO::Job *createListFoldersJob( const KURL &url );
@@ -60,11 +60,11 @@ class ExchangeGlobals
static bool interpretListItemsJob( KPIM::GroupwareDataAdaptor *adaptor,
- KIO::Job *job, const QString &jobData );
+ KIO::Job *job, const TQString &jobData );
static bool interpretCalendarDownloadItemsJob( KCal::CalendarAdaptor *adaptor,
- KIO::Job *job, const QString &jobData );
+ KIO::Job *job, const TQString &jobData );
static bool interpretAddressBookDownloadItemsJob( KABC::AddressBookAdaptor *adaptor,
- KIO::Job *job, const QString &jobData );
+ KIO::Job *job, const TQString &jobData );
};
#endif
diff --git a/kresources/newexchange/kabc_resourceexchange.h b/kresources/newexchange/kabc_resourceexchange.h
index 542b7995..36f3ca2e 100644
--- a/kresources/newexchange/kabc_resourceexchange.h
+++ b/kresources/newexchange/kabc_resourceexchange.h
@@ -32,7 +32,7 @@ class KDE_EXPORT ResourceExchange : public ResourceGroupwareBase
public:
ResourceExchange( const KConfig * );
/* ResourceExchange( const KURL &url,
- const QString &user, const QString &password );*/
+ const TQString &user, const TQString &password );*/
protected:
void init();
};
diff --git a/kresources/newexchange/exchangeconvertercontact.cpp b/kresources/newexchange/exchangeconvertercontact.cpp
index 1e756574..0764d310 100644
--- a/kresources/newexchange/exchangeconvertercontact.cpp
+++ b/kresources/newexchange/exchangeconvertercontact.cpp
@@ -44,12 +44,12 @@ ExchangeConverterContact::ExchangeConverterContact()
#define property( prop ) \
Webdavhandler::addElement( doc, props, prop )
-void ExchangeConverterContact::createRequest( QDomDocument &doc, QDomElement &props )
+void ExchangeConverterContact::createRequest( TQDomDocument &doc, TQDomElement &props )
{
- QDomAttr att_c = doc.createAttribute( "xmlns:c" );
+ TQDomAttr att_c = doc.createAttribute( "xmlns:c" );
att_c.setValue( "urn:schemas:contacts:" );
doc.documentElement().setAttributeNode( att_c );
- QDomAttr att_cal = doc.createAttribute( "xmlns:cal" );
+ TQDomAttr att_cal = doc.createAttribute( "xmlns:cal" );
att_cal.setValue( "urn:schemas:calendar:" );
doc.documentElement().setAttributeNode( att_cal );
@@ -160,15 +160,15 @@ void ExchangeConverterContact::createRequest( QDomDocument &doc, QDomElement &pr
#undef property
-bool ExchangeConverterContact::extractAddress( const QDomElement &node,
+bool ExchangeConverterContact::extractAddress( const TQDomElement &node,
Addressee &addressee, int type,
- const QString &street, const QString &pobox, const QString &location,
- const QString &postalcode, const QString &state, const QString &country,
- const QString &/*countycode*/ )
+ const TQString &street, const TQString &pobox, const TQString &location,
+ const TQString &postalcode, const TQString &state, const TQString &country,
+ const TQString &/*countycode*/ )
{
bool haveAddr = false;
Address addr( type );
- QString tmpstr;
+ TQString tmpstr;
if ( WebdavHandler::extractString( node, street, tmpstr ) ) {
addr.setStreet( tmpstr );
@@ -208,9 +208,9 @@ bool ExchangeConverterContact::extractAddress( const QDomElement &node,
/**
For the complete list of Exchange <=> KABC field mappings see the file
Person.mapping */
-bool ExchangeConverterContact::readAddressee( const QDomElement &node, Addressee &addressee )
+bool ExchangeConverterContact::readAddressee( const TQDomElement &node, Addressee &addressee )
{
- QString tmpstr;
+ TQString tmpstr;
long tmplng;
// The UID is absolutely required!
@@ -283,7 +283,7 @@ bool ExchangeConverterContact::readAddressee( const QDomElement &node, Addressee
// General stuff:
- QStringList tmplst;
+ TQStringList tmplst;
if ( WebdavHandler::extractStringList( node, "Keywords", tmplst ) )
addressee.setCategories( tmplst );
// Exchange sentitivity values:
@@ -345,7 +345,7 @@ bool ExchangeConverterContact::readAddressee( const QDomElement &node, Addressee
if ( WebdavHandler::extractString( node, "spousecn", tmpstr ) )
addressee.insertCustom( "KADDRESSBOOK", "X-SpousesName", tmpstr );
- QDateTime tmpdt;
+ TQDateTime tmpdt;
if ( WebdavHandler::extractDateTime( node, "bday", tmpdt ) )
addressee.setBirthday( tmpdt.date() );
if ( WebdavHandler::extractString( node, "weddinganniversary", tmpstr ) )
@@ -369,19 +369,19 @@ bool ExchangeConverterContact::readAddressee( const QDomElement &node, Addressee
return true;
}
-Addressee::List ExchangeConverterContact::parseWebDAV( const QDomDocument& davdata )
+Addressee::List ExchangeConverterContact::parseWebDAV( const TQDomDocument& davdata )
{
// TODO: Handle multiple addressees per reply!
Addressee::List list;
- QDomElement prop = davdata.documentElement().namedItem( "response" )
+ TQDomElement prop = davdata.documentElement().namedItem( "response" )
.namedItem( "propstat" ).namedItem( "prop" ).toElement();
if ( prop.isNull() ) {
kdDebug()<<"ExchangeConverterContact::parseWebDAV, no response->propstat->prop element!"<<endl;
return list;
}
- QString contentclass;
+ TQString contentclass;
bool success = WebdavHandler::extractString( prop, "contentclass", contentclass );
if ( !success ) {
kdDebug()<<"ExchangeConverterContact::parseWebDAV, No contentclass entry"<<endl;
@@ -414,18 +414,18 @@ kdDebug()<<"ExchangeConverterContact::parseWebDAV, No contentclass entry"<<endl;
domContactProperty( name, addr.phoneNumber( type ).number() );
-QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
+TQDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
{
- QDomDocument doc;
- QDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propertyupdate" );
- QDomElement set = WebdavHandler::addElement( doc, root, "d:set" );
- QDomElement prop = WebdavHandler::addElement( doc, set, "d:prop" );
+ TQDomDocument doc;
+ TQDomElement root = WebdavHandler::addDavElement( doc, doc, "d:propertyupdate" );
+ TQDomElement set = WebdavHandler::addElement( doc, root, "d:set" );
+ TQDomElement prop = WebdavHandler::addElement( doc, set, "d:prop" );
- QDomAttr att_c = doc.createAttribute( "xmlns:c" );
+ TQDomAttr att_c = doc.createAttribute( "xmlns:c" );
att_c.setValue( "urn:schemas:contacts:" );
doc.documentElement().setAttributeNode( att_c );
- QDomAttr att_b = doc.createAttribute( "xmlns:b" );
+ TQDomAttr att_b = doc.createAttribute( "xmlns:b" );
att_b.setValue( "urn:schemas-microsoft-com:datatypes" );
root.setAttributeNode( att_b );
@@ -449,8 +449,8 @@ QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
domContactProperty( "manager", addr.custom( "KADDRESSBOOK", "X-ManagersName" ) );
domContactProperty( "secretarycn", addr.custom( "KADDRESSBOOK", "X-AssistantsName" ) );
- QStringList emails = addr.emails();
- QString prefemail = addr.preferredEmail();
+ TQStringList emails = addr.emails();
+ TQString prefemail = addr.preferredEmail();
if ( emails.contains( prefemail ) )
emails.remove( prefemail );
emails.prepend( prefemail );
@@ -467,27 +467,27 @@ QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
// No value for "personalHomePage"
domContactProperty( "businesshomepage", addr.url().url() );
- QString fburl = KCal::FreeBusyUrlStore::self()->readUrl( addr.preferredEmail() );
+ TQString fburl = KCal::FreeBusyUrlStore::self()->readUrl( addr.preferredEmail() );
if ( !fburl.isEmpty() ) {
domContactProperty( "fburl", fburl );
}
/* FIXME: This doesn't work!
- QStringList cats = addr.categories();
+ TQStringList cats = addr.categories();
if ( cats.isEmpty() ) {
- QDomElement catsnode = WebdavHandler::addElementNS( doc, prop,
+ TQDomElement catsnode = WebdavHandler::addElementNS( doc, prop,
"urn:schemas-microsoft-com:office:office", "Keywords" );
- for ( QStringList::Iterator it = cats.begin(); it != cats.end(); ++it ) {
+ for ( TQStringList::Iterator it = cats.begin(); it != cats.end(); ++it ) {
WebdavHandler::addElementNS( doc, catsnode, "xml:", "v", *it );
}
} else {
// QDomElement catsnode = addProperty( doc, prop,
// "urn:schemas-microsoft-com:office:office", "Keywords", "" );
}*/
// Exchange sentitivity values:
// 0 None, 1 Personal, 2 Private, 3 Company Confidential
- QString value;
+ TQString value;
switch ( addr.secrecy().type() ) {
case KABC::Secrecy::Private: value = "2"; break;
case KABC::Secrecy::Confidential: value = "3"; break;
@@ -574,16 +574,16 @@ QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
// TODO: Birthday and Anniversary:
// FIXME: Exchange uses the date in the form 8/13, i.e. possibly without a
// year! How shall I deal with this?
-/* QDate dt = addr.birthday().date();
- QString str = (dt.isValid())?(dt.toString( Qt::ISODate )):(QString::null);
+/* TQDate dt = addr.birthday().date();
+ TQString str = (dt.isValid())?(dt.toString( Qt::ISODate )):(TQString::null);
if ( !str.isEmpty() ) {
- QDomElement el = domContactProperty( "bday", str );
+ TQDomElement el = domContactProperty( "bday", str );
el.setAttribute( "b:dt", "date" );
}
- dt = QDate::fromString( addr.custom( "KADDRESSBOOK", "X-Anniversary" ), Qt::ISODate );
- str = (dt.isValid())?(dt.toString( Qt::ISODate )):(QString::null);
+ dt = TQDate::fromString( addr.custom( "KADDRESSBOOK", "X-Anniversary" ), Qt::ISODate );
+ str = (dt.isValid())?(dt.toString( Qt::ISODate )):(TQString::null);
if ( !str.isEmpty() ) {
- QDomElement el = domContactProperty( "weddinganniversary", str );
+ TQDomElement el = domContactProperty( "weddinganniversary", str );
el.setAttribute( "b:dt", "date" );
}*/
@@ -592,12 +592,12 @@ QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
KABC::Geo geo = addr.geo();
if ( geo.isValid() ) {
// TODO: Do we need to set any other attribute to make it a float?
- QDomAttr att_cal = doc.createAttribute( "xmlns:cal" );
+ TQDomAttr att_cal = doc.createAttribute( "xmlns:cal" );
att_cal.setValue( "urn:schemas:calendar:" );
doc.documentElement().setAttributeNode( att_cal );
- QDomElement el = domCalendarProperty( "geolatitude", QString::number( geo.latitude() ) );
+ TQDomElement el = domCalendarProperty( "geolatitude", TQString::number( geo.latitude() ) );
el.setAttribute( "b:dt", "float" );
- el = domCalendarProperty( "geolongitude", QString::number( geo.longitude() ) );
+ el = domCalendarProperty( "geolongitude", TQString::number( geo.longitude() ) );
el.setAttribute( "b:dt", "float" );
}
*/
@@ -467,27 +467,27 @@ QDomDocument ExchangeConverterContact::createWebDAV( Addressee addr )
}
} else {
-// QDomElement catsnode = addProperty( doc, prop,
+// TQDomElement catsnode = addProperty( doc, prop,
// "urn:schemas-microsoft-com:office:office", "Keywords", "" );
}*/